def print_lol(the_list,level):
  for each_item in the_list:
    if isinstance(each_item, list):
      print_lol(each_item, level+1)
    else:
        for tab_stop in range(level):
            print("\t", end='')
        print(each_item)



from distutils.core import setup

setup(
        name = 'nestercj',
        version = '1.0.3',
        py_modules = ['nestercj'],
        author = 'codejuro',
        author_email = 'royutsargo@gmail.com',
        url= 'http://www.codejuro.com',
        description = 'A simple printer of nested lists',
    )
